#!/bin/sh
# Licensed Materials - Property of IBM
# OCO Source Materials
# 09N6996
# (C) Copyright IBM Corp. 2007,2008 All Rights Reserved
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.

# This script can be used to configure DB2 databse with Director
# Note: Both the DB2 server and Director server should be on same system

collectParameters ()
{
    while [ $# != 0 ]; do

    case $1 in
     -db)           DB_NAME=$2;;
     -dbLocation)   DB_LOCATION=$2;;
    esac

    shift;shift

    done
}


if [ $# == 0 ]; then
    echo "This script can be used to configure DB2 databse with Director."
    echo "Both the DB2 server and Director server should be on same system."
    echo "Syntax: $0 -db <database_name> -dbLocation <db_location_path>"
    echo "Example: $0 -db db2 -dbLocation /opt/ibm/db2/V9.5"
    exit 1
else
    collectParameters $@
fi

if [ "$DB_NAME" != db2 ]; then
    echo "Only the configuration of db2 database is supported by this script"
    exit 2
fi

# Prepare DB2 for Director.
echo "Preparing DB2 to work with Director..."

#Create user groups. Group ID not passed, allowing to use default ID
 
groupadd db2iadm1
groupadd db2fadm1
groupadd dasadm1

# Create users db2inst1, db2fenc1, dasusr1 and db2usr01 and assign passwords to those users
# useradd command is run without -u <id> option, allow to use default ID

pass=$(perl -e 'print crypt(pwdinst1, "password")')
useradd -g db2iadm1 -m -d /home/db2inst1 -p $pass db2inst1

pass=$(perl -e 'print crypt(pwdfenc1, "password")')
useradd -g db2fadm1 -m -d /home/db2fenc1 -p $pass db2fenc1

pass=$(perl -e 'print crypt(pwdasusr1, "password")')
useradd -g dasadm1 -m -d /home/dasusr1 -p $pass dasusr1

pass=$(perl -e 'print crypt(pwdusr01, "password")')
useradd -g db2iadm1 -m -d /home/db2usr01 -p $pass db2usr01

#Create DB2 instance

if [ ! -e $DB_LOCATION/instance ]; then
    echo "DB2 is not installed or DB location is invalid"
    echo "Configuration of DB2 failed...exiting"
    exit 3
fi

cd $DB_LOCATION/instance
./db2icrt -a SERVER -p 50000 -u db2fenc1 db2inst1

# establish the following environment variables
export CLASSPATH=.:/home/db2inst1/sqllib/java/db2jcc.jar:/home/db2inst1/sqllib/java/db2jcc_license_cu.jar
export PATH=$PATH:/home/db2inst1/sqllib/bin:/home/db2inst1/sqllib/adm
export LD_LIBRARY_PATH=/home/db2inst1/sqllib/lib32
export DB2_HOME=/home/db2inst1/sqllib

# login to db2inst1 user account, create IBMDIR01 database and set DB2_WORKLOAD variable with TPM
sudo -u db2inst1 db2start
sudo -u db2inst1 db2 "create database IBMDIR01"
sudo -u db2inst1 db2set "DB2_WORKLOAD=TPM"
sudo -u db2inst1 db2stop force
sudo -u db2inst1 db2start

# Configure DB2 with Director
echo "Configuring DB2 with Director..."

DIRECTOR_ROOT=/opt/ibm/director

cd $DIRECTOR_ROOT/proddata/

rm -f cfgdbcmd.rsp
echo  "DbmsApplication = DB2" >> cfgdbcmd.rsp
echo  "DbmsTcpIpListenerPort = 50000" >> cfgdbcmd.rsp
echo  "DbmsServerName = localhost" >> cfgdbcmd.rsp
echo  "DbmsDatabaseName = IBMDIR01" >> cfgdbcmd.rsp
echo  "DbmsUserId = db2usr01" >> cfgdbcmd.rsp
echo  "DbmsDatabaseAppHome = /home/db2inst1/sqllib" >> cfgdbcmd.rsp
echo  "DbmsPassword = pwdusr01" >> cfgdbcmd.rsp

echo "***********************************"
echo "Enter the following input when asked"
echo "user ID that you want to use for Tivoli Provisioning Manager: db2inst1"
echo "password for the Tivoli Provisioning Manager user ID: pwdinst1"
echo "user ID that you want to use for connecting to the database: db2usr01"
echo "password for the database user ID: pwdusr01"
echo "***********************************"

#run `/opt/ibm/director/bin/configDB.sh` responding to to the prompts as follows:
#Enter the user ID that you want to use for Tivoli Provisioning Manager:
#`db2inst1`
#Enter the password for the Tivoli Provisioning Manager user ID:
#`pwdinst1`
#Enter the user ID that you want to use for connecting to the database:
#`db2usr01`
#Enter the password for the database user ID:
#`pwdusr01`

$DIRECTOR_ROOT/bin/configDB.sh

# run the cfgdbcmd.sh script
$DIRECTOR_ROOT/bin/cfgdbcmd.sh -dbAdmin db2inst1 -dbAdminPW pwdinst1 -dbLocal true -noPrompt false -rspfile /opt/ibm/director/proddata/cfgdbcmd.rsp

if [ $? -eq 0 ]; then
    echo "Configuration of DB2 with Director Success..."
else
    echo "Configuration of DB2 with Director Failed..."
    exit $?
fi    

# Configuring agent manager
echo "Starting configuration of Agent Manager..."
USERID=userid
AMPASSWD=ampwd
REGPASSWD=regpwd

$DIRECTOR_ROOT/bin/configAgtMgr.sh -user $USERID -agtmgrpass $AMPASSWD -regpass $REGPASSWD

if [ $? == 0 ]; then
    echo "Configuring Agent Manager Success..."
else
    echo "Configuring Agent Manager Failed..."
    exit $?
fi

#Start the Director Driver
echo "Starting Director Server..."
$DIRECTOR_ROOT/bin/smstart
