#!/bin/sh
# Licensed Materials - Property of IBM
# OCO Source Materials
# 09N6996
# (C) Copyright IBM Corp. 2008,2009 All Rights Reserved
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.

# This script can be used to
# 1. Configure system related attributes like IP-Address, Hostname 
# 2. Configure AgentManger
# 3. Configure UID and TIVGUID

# This script is used to configure the system related attributes present in 
# director files. The attributes targeted here are local system IP-Address,
# hostname
# Following actions are performed by the script:
# updates /opt/ibm/director/tpm/xml/tpmserver.xml
# updates /opt/ibm/director/tpm/config/tcdrivermanager.xml
# updates /opt/ibm/director/lwi/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/WEB-INF/classes/resources/AgentManager.properties
# updates All *.jnlp files under /opt/ibm/director/lwi/runtime/ - com.ibm.director.console.lic.jnlp and com.ibm.director.storage.lic.jnlp and others if any
# All the binary files under /opt/ibm/director/tpm/hatterastc
# updates the ceritificate $LWI_PREFIX/security/keystore/ibmjsse2.jks
# updates hostname in /opt/tivoli/ep.reg file
# updates cimom related files under /opt/ibm/icc/cimom/repository/*/instances

# Configures TIVGUID
# Configures UID
# Configures Agent Manager

collectParameters ()
{
    while [ $# != 0 ]; do
    
    case $1 in
     -ip)           IPADDRESS=$2;;
     -hostname)     FULLSERVERNAME=$2
                    SERVERNAME=`/bin/hostname -s`
                    ;;
     -user)         USERID=$2;;
     -agtmgrpass)   AMPASSWD=$2;;
     -regpass)      REGPASSWD=$2;;
    esac
      
    shift;shift

    done
}

DIRECTOR_ROOT=/opt/ibm/director
TPM_HOME=$DIRECTOR_ROOT/tpm
LWI_PREFIX=$DIRECTOR_ROOT/lwi
OS_TYPE=`uname`

#Ideally system IP and other details(hostname, data for db config) should be passed to this script
#TODO: If no arguments prompt user with proper syntax

#Values for Agent Manager Configuration
USERID=userid
AMPASSWD=ampwd
REGPASSWD=regpwd

if [ $# == 0 ]; then
    echo "Syntax: $0 -ip <ipaddress> -hostname <full_hostname> [-user <resource_manager_userid> -agtmgrpass <resource_manager_password> -regpass <agent_registration_password>]"
    echo "Specifying ip address and hostname is mandatory"
    echo "Specifying -user, -agtmgrpass and -regpass are optional. They can be used for Agent Manager configuration. Default values will be used if they are not specified"
    exit 1    
else
    collectParameters $@
fi

echo "Configuring system properties(IP-Address, hostname)..."

#config tpmserver.xml file

default_ip=default_ip
default_hostname=default_hostname
default_fullhostname=default_fullhostname

FULLHOSTNAME=$FULLSERVERNAME

cd $TPM_HOME/xml

# IPADRESS CANT BE EMPTY. COMMENT THE BELOW SCRIPT FOR NOW
#if [ "$IPADDRESS" == "" ]; then
#     IPADDRESS=`ifconfig eth0 | grep inet6 | grep Global | grep 2001 | awk '{print $3}' | awk -F/ '{print $1}' | sed '1!d'`
#     if [ "$IPADDRESS" == "" ]; then
#       IPADDRESS=`ifconfig eth0 | grep inet6 | grep Global | sed 1!d | awk '{print $3}' | awk -F/ '{print $1}' | sed '1!d'`
#     fi
#fi


# Note: We are setting only IP, full and short hostname. No need to set other attributes username, pwd, repository
perl -pi -e "s/$default_fullhostname/$FULLHOSTNAME/g", -e "s/$default_hostname/$SERVERNAME/g", -e "s/$default_ip/$IPADDRESS/g" tpmserver.xml

# code to configure /opt/ibm/director/tpm/config/tcdrivermanager.xml

oldValue="property name=\"tpmipaddress\" location=\"$default_ip\""
newValue="property name=\"tpmipaddress\" location=\"$IPADDRESS\""

perl -pi -e "s/$oldValue/$newValue/g" $TPM_HOME/config/tcdrivermanager.xml

resetInFile()
{
    file=$1
    if [ -e $file ]; then
        perl -pi -e "s/$default_ip/$IPADDRESS/g", -e "s/$default_fullhostname/$FULLHOSTNAME/g", -e "s/$default_hostname/$SERVERNAME/g" $file
    fi
}

# This method takes directory name as argument.
# It sets IP, hostname(full and small) in all files under the specified directort
resetInDir()
{
    grep -rEl "$default_fullhostname|$default_hostname|$default_ip" "$1" | while read file
    do resetInFile $file; done
}

# code to configure com.ibm.director.console.lic.jnlp and com.ibm.director.storage.lic.jnlp
# Find all the *.jnlp files under lwi/runtime, loop through each of them and set in them

find $LWI_PREFIX/runtime -type f -name '*.jnlp' | while read file; do resetInFile $file; done

# configure IP-Address in all the binary files under /opt/ibm/director/tpm/hatterastc
DERBY_EXPLORER=`find $DIRECTOR_ROOT/bin/config -name derbyexplorer.jar`
DERBY_HOME=$DIRECTOR_ROOT/lwi/runtime/database/eclipse/plugins/org.apache.derby.core_10.3.3.1
CLASSPATH=$DERBY_HOME/derby.jar:$DERBY_HOME/derbyclient.jar:$DERBY_EXPLORER

if [ DERBY_EXPLORER != "" ]
then
    $DIRECTOR_ROOT/jre/bin/java -cp $CLASSPATH com.ibm.sysmgt.derby.explorer.DerbyExplorer $TPM_HOME/hatterastc -user tioadmin -pass think4me -search '$default_ip|$IPADDRESS' -search '$default_fullhostname|$FULLHOSTNAME' -search '$default_hostname|$SERVERNAME'
fi

# configure IP-Address and hostname in binary file $LWI_PREFIX/security/keystore/ibmjsse2.jks

cd $LWI_PREFIX/security/keystore/
#resetInFile ibmjsse2.jks
#configure using keytool
$DIRECTOR_ROOT/jre/bin/keytool -selfcert -alias lwiks -dname CN=$FULLHOSTNAME,O=IBM,C=US -validity 365 -keystore $LWI_PREFIX/security/keystore/ibmjsse2.jks -keypass ibmpassw0rd -storepass ibmpassw0rd

############### Configure Agent related files ###############

# Not updating any agent files manually, if needed uncomment appropriate lines

# configure IP-Address in org.eclipse.core.runtime.preferences.OSGiPreferences.11.prefs

cd $DIRECTOR_ROOT/agent/conf/.settings
#resetInFile org.eclipse.core.runtime.preferences.OSGiPreferences.11.prefs

# configure IP and hostname in all files under /opt/ibm/director/agent/conf/.settings
# There are many other files in this directory that contain the IP/hostname
#resetInDir $DIRECTOR_ROOT/agent/conf/.settings

# Configure IP-Address, hostname  in 
# agent/runtime/agent/subagents/eclipse/plugins/com.ibm.usmi.agent.coreagent.usmiimpl_*/data/coreagent.dat
# agent/runtime/agent/subagents/eclipse/plugins/com.ibm.usmi.client.ipc_1.0.0/data/srvreg.ini binary file 
# agent/runtime/agent/config/endpoint.properties and agent/runtime/agent/backup/endpoint.properties
# agent/runtime/agent/config/status.out
# agent/runtime/agent/subagents/director/ipc/data/srvreg.ini

cd $DIRECTOR_ROOT/agent/runtime/agent

#find . -name coreagent.dat | while read file; do resetInFile $file; done

#find . -name srvreg.ini | while read file; do resetInFile $file; done

#find . -name endpoint.properties | while read file; do resetInFile $file; done

#find . -name status.out | while read file; do resetInFile $file; done

# reset hostname in files under /opt/ibm/director/agent/data/
#resetInDir $DIRECTOR_ROOT/agent/data

############### Configure Agent related files end###############

# update IP/hostname in files under /opt/tivoli/
# Only the /opt/tivoli/ep.reg contains the hostname. No files under /opt/tivoli/ contain IP

cd /opt/tivoli/
find . -name ep.reg | while read file; do resetInFile $file; done

# update in files under /opt/ibm/icc/cimom
cd /opt/ibm/icc/cimom
resetInDir repository/*/instances

# reset hostname in binary file /opt/ibm/director/cimom/data/health.dat

cd $DIRECTOR_ROOT/cimom/data
#resetInFile health.dat

# code to configure AgentManager.properties

cd $LWI_PREFIX/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/WEB-INF/classes/resources

DOMAIN_NAME=`echo $FULLSERVERNAME | awk -F. -v ORS="." '{for (i = 2; i <= NF; i++) print $i}' | sed 's/.$//'`

perl -pi -e "s/ARS.domainName.*$/ARS.domainName = $DOMAIN_NAME/g", -e "s/ARS.host.*$/ARS.host = $IPADDRESS/g" AgentManager.properties

echo "Configuring system properties(IP-Address, hostname) Success..."

if [ $OS_TYPE != "AIX" -a $OS_TYPE != "aix" ]; then
    echo "Starting services..."

    # Director won't work properly if slpd is active
    # stop slpd if running and disable it from starting again
    rcslpd stop #equivalent to /etc/init.d/slpd stop
    insserv -r slpd

    /etc/init.d/ibmsa start
    /etc/init.d/tier1slpinst start
    /etc/init.d/cimlistenerd start
    /etc/init.d/cimserverd start
fi

# For reconfiguring TIVGUID, Generate new TIVGUID
echo "Configuring TIVGUID..."
if [ $OS_TYPE == "AIX" -o $OS_TYPE == "aix" ]; then
    /usr/tivoli/guid/tivguid -Write -New
else
    /opt/tivoli/guid/tivguid -Write -New
fi

if [ $? == 0 ]; then
    echo "Configuring TIVGUID Success..."
else
    echo "Configuring TIVGUID Failed..."
    exit $?
fi

#remove existing uid file and generate new uid
echo "Configuring UID..."
cd /etc/ibm/director/twgagent
rm -f twgagent.uid
$DIRECTOR_ROOT/bin/genuid
if [ $? == 0 ]; then
    echo "Configuring UID Success..."
else
    echo "Configuring UID Failed..."
    exit $?
fi

echo "Starting Common agent..."
$DIRECTOR_ROOT/agent/runtime/agent/bin/endpoint.sh start

echo "Starting configuration of Agent Manager..."

$DIRECTOR_ROOT/bin/configAgtMgr.sh -user $USERID -agtmgrpass $AMPASSWD -regpass $REGPASSWD

if [ $? == 0 ]; then
    echo "Configuring Agent Manager Success..."
else
    echo "Configuring Agent Manager Failed..."
fi
