#!/bin/sh

extract_and_update()
{
    install_location=$1
    
    if [ ! -e $install_location ]; then
       echo "Error: Specified file/directory doesnot exist"
       exit 1
    fi
    
    if [ -d $install_location ]; then
       cd $install_location
    else
       zipLocation=`dirname $install_location`
       cd $zipLocation
       gzip -d $install_location

       #strip of the .gz in the input and extract using tar
       updatedFilename=`echo $install_location | sed "s/.gz//"`
       tar -xf $updatedFilename
       if [ $? != 0 ]; then 
           echo "Extraction of file failed, please extract manually and try again"
           exit $?
       fi
    fi

    #Update installer.properties file to perform silent installation
    file=installer.properties
    cp $file $file.bak
    cat $file.bak | sed -e "s/INSTALLER_UI=Swing/INSTALLER_UI=silent/g" -e "s/$LICENSE_ACCEPTED$=false/$LICENSE_ACCEPTED$=true/g"> $file

    # TODO: Above code will change the value for INSTALLER_UI even in comment, replace it back with original value
}

install_ssm()
{
    if [ -e /opt/ibm/director/ElectronicServiceAgent ]; then
       echo "Service and Support Manager is already installed"
       exit 1
    fi

    ssm_Install_Location=$1
    echo "Installing Service and Support Manager..."

    # extract the zip (if not extracted) and update the installer.properties file for silent installation
    extract_and_update $ssm_Install_Location

    # Install SSM using the install script of SSM
    ./IBMSystemsDirector-ESA-Setup.sh

    if [ $? != 0 ]; then
        echo "Installation of Service and Support Manager failed..."
    else
        echo "Installation of Service and Support Manager Success..."
    fi
    exit $?
}

install_aem()
{
    if [ -e /opt/ibm/director/ActiveEnergyManager ]; then
       echo "Active Energy Manager is already installed"
       exit 1
    fi
    
    aem_Install_Location=$1
    echo "Installing Active Energy Manger..."

    # extract the zip (if not extracted) and update the installer.properties file for silent installation
    extract_and_update $aem_Install_Location

    # Install SSM using the install script of SSM
    ./IBMSystemsDirector-AEM-Setup.sh

    echo "AEM return code: $?"
    if [ $? != 0 ]; then
        echo "Installation of Active Energy Manager failed..."
    else
        echo "Installation of Active Energy Manager Success..."
    fi
    exit $?
}

if [ $# == 0 ]; then
    echo "This script can be used to install" 
    echo "1. Active Energy Manager"
    echo "2. Service and Support Manager"
    echo "Syntax: $0 -ssm <ssm_installables_location> -aem <aem_installables_location>"
    echo "Note: Specifying atleast one of the options -ssm or -aem is necessary
The installables_location input can either be the zipped installer downloaded from the website or the folder name that contains the extracted installables
ex: $0 -ssm manager/SysDir6_1_Service_Support_Linux_x86.tar.gz.gz -aem aemFiles
In above example aemFiles is the directory that contains the extracted installables of aem"
    exit 1   
fi

while [ $# != 0 ]; do

    case $1 in
     -ssm)          install_ssm $2;;
     -aem)          install_aem $2;;
    esac

    shift;shift

done

