#!/bin/sh
# Licensed Materials - Property of IBM
# OCO Source Materials
# 09N6996
# (C) Copyright IBM Corp. 2007,2008 All Rights Reserved
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.

# This script is used to clean/reset the system related attributes present in 
# director files. The attributes targeted here are local system IP-Address,
# hostname, password. This script also clears the cerificates and LWI DB created
# during AM configuration

# Following actions are performed during preinstallcleanup.sh:

# Unmanage the agent
# Stop slp, cim and agent services

# update /opt/ibm/director/tpm/xml/tpmserver.xml
# update /opt/ibm/director/tpm/config/tcdrivermanager.xml
# update all *.jnlp files under /opt/ibm/director/lwi/runtime/
# All the binary files under /opt/ibm/director/tpm/hatterastc
# Delelte/truncate files that have IP/hostname under /opt/ibm/director/agent
# Updates cimom related files under /opt/ibm/icc/cimom/repository/*/instances

# Update /opt/ibm/director/lwi/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/WEB-INF/classes/resources/AgentManager.properties
# Remove /opt/ibm/director/proddata/agentmanagerconfig.properties
# Remove /opt/ibm/director/lwi/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/certs
# Remove /opt/ibm/director/lwi/runtime/agentmanager/toolkit/certs
# Remove /opt/ibm/director/lwi/runtime/core/DATABASE
# Remove AgentManager.InstID entry from AgentManager.properties
# Update $LWI_PREFIX/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/config/Authorization.xml
# delete $LWI_PREFIX/runtime/agentmanager/conf/cas-manager-database.properties
# Truncate /opt/ibm/director/lwi/conf/virtualhost.properties
# update /opt/ibm/director/lwi/conf/webcontainer.properties. Delete entries that contain 9511|9512|9513
# delete /opt/ibm/director/lwi/append/cas-manager-webcontainer.properties
# update hostname under /opt/tivoli/ep.reg

DIRECTOR_ROOT=/opt/ibm/director
TPM_HOME=$DIRECTOR_ROOT/tpm
LWI_PREFIX=$DIRECTOR_ROOT/lwi

default_ip=default_ip
default_hostname=default_hostname
default_fullhostname=default_fullhostname

echo "Unmanging the agent..."

$DIRECTOR_ROOT/agent/runtime/agent/toolkit/bin/configure.sh -unmanaged -force
if [ $? == 0 ]; then
    echo "Unmanaging agent Success..."
else
    echo "Unmanaging agent Failed..."
    exit $?
fi

OS_TYPE=`uname`

# stop agent, slp and cim services
echo "Stopping services..."

/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh stop

if [ $OS_TYPE != "AIX" -a $OS_TYPE != "aix" ]; then
    /etc/init.d/ibmsa stop
    /etc/init.d/tier1slpinst stop
    /etc/init.d/cimlistenerd stop
    /etc/init.d/cimserverd stop
    
    # Director won't work properly if slpd is active
    # stop slpd if running and disable it from starting again
    rcslpd stop #equivalent to /etc/init.d/slpd stop
    insserv -r slpd
fi

echo "Resetting system properties(IP-Address, hostname) ..."

# Reset the file tpmserver.xml and bring it to default initial level
# Reset all the attributes that were set during install

cd $TPM_HOME/xml

# Get the attrbute values from tpmserver.xml file
IPADDRESS=`cat tpmserver.xml | grep "is the ip address of the management interface" | cut -f2 -d' '`
SERVERNAME=`cat tpmserver.xml | grep "is the server name as returned by CLI hostname" | cut -f2 -d' '`
USERNAME=`cat tpmserver.xml | grep "is the username of the administrator" | cut -f2 -d' '`
PASSWORD=`cat tpmserver.xml | grep "is an encrypted password for the user" | cut -f2 -d' '`
REPOSITORY_DIR=`cat tpmserver.xml | grep "is the directory location for the repository" | cut -f2 -d' '`
FULL_HOSTNAME=`cat tpmserver.xml | grep "is the fully qualified host name for local machine" | cut -f2 -d' '`

# If the above variables are empty try to get the values by searching for other strings in the tpmserver.xml file

if [ "$IPADDRESS" == "" ]; then
        IPADDRESS=`cat tpmserver.xml | grep "<network-interface ipaddress=" | cut -f2 -d'=' | cut -f2 -d"\""`
fi
if [ "$SERVERNAME" == "" ]; then
        SERVERNAME=`cat tpmserver.xml | grep "<server name="  | cut -f2 -d'=' | cut -f2 -d"\""`
fi
if [ "$USERNAME" == "" ]; then
        temp=`cat tpmserver.xml | grep "<password-credentials username="  | cut -f2 -d'=' | cut -f2 -d"\""` 
        USERNAME=`echo $temp  | cut -f1 -d' '`
fi
if [ "$PASSWORD" == "" ]; then
        temp=`cat tpmserver.xml | grep "<password-credentials username="  | cut -f3 -d' ' | cut -f2 -d"\""`
        PASSWORD=`echo $temp  | cut -f1 -d' '`
fi
if [ "$FULL_HOSTNAME" == "" ]; then
        FULL_HOSTNAME=`cat tpmserver.xml | grep "<property name=\"mail.smtp.from\"" | cut -f3 -d'='  | cut -f2 -d"\"" | cut -f2 -d"@"`
fi

# If the variables are still empty then set them to values got from OS/default
if [ "$IPADDRESS" == "" ]; then
	IPADDRESS=`ifconfig | grep Bcast | awk '{print $2}' | awk -F: '{print $2}' | sed '1!d'`
fi
if [ "$SERVERNAME" == "" ]; then
	SERVERNAME=`/bin/hostname -s`
fi
if [ "$USERNAME" == "" ]; then
    USERNAME="root"
fi
if [ "$REPOSITORY_DIR" == "" ]; then
    REPOSITORY_DIR=$TPM_HOME/repository
fi
if [ "$FULL_HOSTNAME" == "" ]; then
    if [ $OS_TYPE == "AIX" -o $OS_TYPE == "aix" ]; then
        FULL_HOSTNAME=`/bin/hostname`
    else
        FULL_HOSTNAME=`/bin/hostname -f`
    fi
fi

# Search and reset each of the attributes
# Note: We are reseting only IP, full and short hostname. We are not reseting username, pwd, repository

perl -pi -e "s/$FULL_HOSTNAME/$default_fullhostname/g", -e "s/$SERVERNAME/$default_hostname/g", -e "s/$IPADDRESS/$default_ip/g" tpmserver.xml

# Sometimes the fully qualified hostname wil be same as short name.
# In those cases default_hostname is put as default value for fully qualified hostname,
# but we want default_fullhostname as the default value for that. This is because we need
# to differentiate them so that we can reset back to proper values during reconfiguration.
# Manually setting the value to default_fullhostname at places where full hostname has to be present

perl -pi -e "s/$default_hostname is the fully qualified host name for local machine/$default_fullhostname is the fully qualified host name for local machine/g" tpmserver.xml

perl -pi -e "s/property name=\"mail.smtp.from\" value=\"$USERNAME@$default_hostname\"/property name=\"mail.smtp.from\" value=\"$USERNAME@$default_fullhostname\"/g" tpmserver.xml

# code to reset /opt/ibm/director/tpm/config/tcdrivermanager.xml

oldValue="property name=\"tpmipaddress\" location=\"$IPADDRESS\""
newValue="property name=\"tpmipaddress\" location=\"$default_ip\""

perl -pi -e "s/$oldValue/$newValue/g" $TPM_HOME/config/tcdrivermanager.xml

FULLHOSTNAME=$FULL_HOSTNAME

# This method is used to reset IP, hostname(full and small) in the file specified in $1
resetInFile()
{
    file=$1
    if [ -e $file ]
    then
        perl -pi -e "s/$IPADDRESS/$default_ip/g", -e "s/$FULLHOSTNAME/$default_fullhostname/g", -e "s/$SERVERNAME/$default_hostname/g" $file
    fi
}

# This method takes directory name as argument.
# It resets IP, hostname(full and small) in all files under the specified directort
resetInDir()
{
    grep -rEl "$FULLHOSTNAME|$SERVERNAME|$IPADDRESS" "$1" | while read file
    do resetInFile $file; done
}

# code to reset in the jnlp files
# They are currently present in com.ibm.director.console.lic.jnlp and com.ibm.director.storage.lic.jnlp
# Find all the *.jnlp files under lwi/runtime, loop through each of them and reset in them

find $LWI_PREFIX/runtime -type f -name '*.jnlp' | while read file; do resetInFile $file; done

# reset IP-Address in all the binary files under /opt/ibm/director/tpm/hatterastc

DERBY_EXPLORER=`find $DIRECTOR_ROOT/bin/config -name derbyexplorer.jar`
DERBY_HOME=$DIRECTOR_ROOT/lwi/runtime/database/eclipse/plugins/org.apache.derby.core_10.3.3.1
CLASSPATH=$DERBY_HOME/derby.jar:$DERBY_HOME/derbyclient.jar:$DERBY_EXPLORER

if [ DERBY_EXPLORER != "" ]
then
    $DIRECTOR_ROOT/jre/bin/java -cp $CLASSPATH com.ibm.sysmgt.derby.explorer.DerbyExplorer $TPM_HOME/hatterastc -user tioadmin -pass think4me -search "$IPADDRESS|$default_ip" -search "$FULLHOSTNAME|$default_fullhostname" -search "$SERVERNAME|$default_hostname"
fi

############### Reset in Agent related files ###############

# It is suggested that we need not update IP/hostname in agent related files
# So, for the below files, we are either ignoring, truncating or deleting the files.

# code to reset IP-Address in org.eclipse.core.runtime.preferences.OSGiPreferences.11.prefs

cd $DIRECTOR_ROOT/agent/conf/.settings
#resetInFile org.eclipse.core.runtime.preferences.OSGiPreferences.11.prefs
echo "" > org.eclipse.core.runtime.preferences.OSGiPreferences.11.prefs

# reset IP and hostname in all files under /opt/ibm/director/agent/conf/.settings
# There are many other files in this directory that contain the IP/hostname
#resetInDir $DIRECTOR_ROOT/agent/conf/.settings
rm -rf instancecache

# code to reset IP-Address, hostname  in 
# agent/runtime/agent/subagents/eclipse/plugins/com.ibm.usmi.agent.coreagent.usmiimpl_*/data/coreagent.dat
# agent/runtime/agent/subagents/eclipse/plugins/com.ibm.usmi.client.ipc_1.0.0/data/srvreg.ini binary file 
# agent/runtime/agent/config/endpoint.properties and agent/runtime/agent/backup/endpoint.properties
# agent/runtime/agent/config/status.out
# agent/runtime/agent/subagents/director/ipc/data/srvreg.ini

cd $DIRECTOR_ROOT/agent/runtime/agent

find . -name coreagent.dat | while read file; do echo "" > $file; done

find . -name srvreg.ini | while read file; do echo "" > $file; done

#find . -name endpoint.properties | while read file; do resetInFile $file; done

#find . -name status.out | while read file; do resetInFile $file; done

# reset hostname in files under /opt/ibm/director/agent/data/
#resetInDir $DIRECTOR_ROOT/agent/data
rm -rf $DIRECTOR_ROOT/agent/data/*.txt

############### Reset in Agent related files end ###############

############### Reset in cimom files ###############

# reset hostname in binary file /opt/ibm/director/cimom/data/health.dat
# truncate health.dat
cd $DIRECTOR_ROOT/cimom/data
echo "" > health.dat

# update in files under /opt/ibm/icc/cimom
cd /opt/ibm/icc/cimom
resetInDir repository/*/instances

############### Reset in cimom files end ###############

# reset IP-Address and hostname in binary file $LWI_PREFIX/security/keystore/ibmjsse2.jks
# reset using keytool
# No need to create a certificate with default name, just create one while configuring. Commenting below line

#$DIRECTOR_ROOT/jre/bin/keytool -selfcert -alias lwiks -dname CN=$default_fullhostname,O=IBM,C=US -validity 365 -keystore $LWI_PREFIX/security/keystore/ibmjsse2.jks -keypass ibmpassw0rd -storepass ibmpassw0rd

# Note: We are retaining all the database related configurations.
# reset the $DIRECTOR_ROOT/proddata/cfgdbcmd.rsp file. Reset the all config details related to Derby

#cd $DIRECTOR_ROOT/proddata
#cp cfgdbcmd.rsp cfgdbcmd.rsp.bak

#cat cfgdbcmd.rsp.bak | sed -e "s/DbmsApplication/;DbmsApplication/" -e "s/DbmsTcpIpListenerPort/;DbmsTcpIpListenerPort/" -e "s/DbmsServerName = .*$/;DbmsServerName = xxxxx/" -e "s/DbmsDatabaseName = .*$/;DbmsDatabaseName = xxxxx/" -e "s/DbmsUserId = .*$/;DbmsUserId = xxxxx/" -e "s/DbmsDatabaseAppHome=.*$/;DbmsDatabaseAppHome = xxxxx/" -e "s/DbmsDatabaseHome = .*$/;DbmsDatabaseHome = xxxxx/" -e "s/DbmsPassword = .*$/;DbmsPassword = xxxxx/" > cfgdbcmd.rsp

#rm -f cfgdbcmd.rsp.bak

# code to reset password in dcm.xml

#cd $TPM_HOME/config
#cp dcm.xml dcm.xml.bak

#cat dcm.xml.bak| sed -e "s/<password>.*$/<password>think4me<\/password>/" > dcm.xml
#rm -f dcm.xml.bak

# code to reset IP in all files inside /opt/ibm/director/lwi/runtime/director/eclipse/plugins folder
# Note: No instances found under this directory. So commenting the code

#cd $DIRECTOR_ROOT/lwi/runtime/director/eclipse/plugins

#filenames=`grep -r $IPADDRESS  . | cut -f1 -d':'`
#for file in $filenames
#do
#    resetInFile $file
#done

############### Reset in Agent Manager related files ###############

echo "Resetting Agent Manager related data ..."

# delete the Agent/AM cached data. This is removed by smreset itself

cd $DIRECTOR_ROOT/data
rm -rf AMData
rm -f CasQueryDate.*
find . -type f -name 'com.ibm.usmi.client.cas*' | while read file; do rm -f $file; done
 
AGENT_MANAGER=$DIRECTOR_ROOT/lwi/runtime/agentmanager

# reset AgentManager.properties
cd $AGENT_MANAGER/eclipse/plugins/com.ibm.tivoli.cas.manager/WEB-INF/classes/resources

DEFAULT_DOMAINNAME=sample.org
DEFAULT_AGENTPWD=changeMe

perl -pi -e "s/ARS.domainName = .*$/ARS.domainName = $DEFAULT_DOMAINNAME/g", -e "s/ARS.host = .*$/ARS.host = $default_ip/g", -e "s/Registration.Agent.Access.Password.*$/Registration.Agent.Access.Password = $DEFAULT_AGENTPWD/g" AgentManager.properties

# Code to remove certificates and AM database. Needed for AM reconfiguration
# Delete jks, pwd  files and other files needed for AM reconfiguration
rm -f $DIRECTOR_ROOT/proddata/agentmanagerconfig.properties

rm -rf $AGENT_MANAGER/eclipse/plugins/com.ibm.tivoli.cas.manager/certs/

rm -rf $AGENT_MANAGER/toolkit/certs

rm -rf $DIRECTOR_ROOT/lwi/runtime/core/DATABASE/

#delete the os.guid file that caches TIVGUID
rm -f $AGENT_MANAGER/eclipse/plugins/com.ibm.tivoli.cas.manager/os.guid

# Remove AgentManager.InstID entry from AgentManager.properties
cd $LWI_PREFIX/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/WEB-INF/classes/resources
perl -pi -e 's/AgentManager.InstID=.*$//' AgentManager.properties

#Note: The below changes related to AM are optional. Config works fine even without these changes
 
# revert back Authorization.xml
cd $LWI_PREFIX/runtime/agentmanager/eclipse/plugins/com.ibm.tivoli.cas.manager/config
perl -pi -e 's/<user id=.*$/<user id="manager" password="password" \/>/' Authorization.xml
perl -pi -e 's/<authType name=.*$/<authType name="*" userList="manager" \/>/' Authorization.xml

# delete $LWI_PREFIX/runtime/agentmanager/conf/cas-manager-database.properties
rm -f $LWI_PREFIX/runtime/agentmanager/conf/cas-manager-database.properties

# Truncate /opt/ibm/director/lwi/conf/virtualhost.properties
cd $LWI_PREFIX
echo "" > $LWI_PREFIX/conf/virtualhost.properties

# update /opt/ibm/director/lwi/conf/webcontainer.properties. Delete entries that contain 9511|9512|9513
perl -ni.bak -e 'print unless /\.951[12]/' $LWI_PREFIX/conf/webcontainer.properties

# delete /opt/ibm/director/lwi/append/cas-manager-webcontainer.properties
rm -rf $LWI_PREFIX/append/cas-manager-webcontainer.properties

############### Reset in Agent Manager related files end ###############

# update IP/hostname in files under /opt/tivoli/
# Only the /opt/tivoli/ep.reg contains the hostname. No files under /opt/tivoli/ contain IP

cd /opt/tivoli/
find . -name ep.reg | while read file; do resetInFile $file; done

echo "Cleanup completed successfully ..."
